OC.L10N.register(
    "core",
    {
    "No image or file provided" : "لم يتم توفير صورة أو ملف",
    "Unknown filetype" : "نوع الملف غير معروف",
    "Invalid image" : "الصورة غير صالحة",
    "%s password reset" : "تمت إعادة ضبط كلمة مرور %s",
    "Error deleting tag(s)" : "خطأ أثناء حذف العلامة (العلامات)",
    "Updated database" : "قاعدة بيانات المرفوعات",
    "Sunday" : "الأحد",
    "Monday" : "الأثنين",
    "Tuesday" : "الثلاثاء",
    "Wednesday" : "الاربعاء",
    "Thursday" : "الخميس",
    "Friday" : "الجمعه",
    "Saturday" : "السبت",
    "Sun." : "الأحد",
    "Mon." : "الأثنين",
    "Tue." : "الثلاثاء",
    "Wed." : "الأربعاء",
    "Thu." : "الخميس",
    "Fri." : "الجمعة",
    "Sat." : "السبت",
    "January" : "كانون الثاني",
    "February" : "شباط",
    "March" : "آذار",
    "April" : "نيسان",
    "May" : "أيار",
    "June" : "حزيران",
    "July" : "تموز",
    "August" : "آب",
    "September" : "أيلول",
    "October" : "تشرين الاول",
    "November" : "تشرين الثاني",
    "December" : "كانون الاول",
    "Jan." : "كانون الثاني",
    "Feb." : "شباط",
    "Mar." : "آذار",
    "Apr." : "نيسان",
    "May." : "أيار",
    "Jun." : "حزيران",
    "Jul." : "تموز",
    "Aug." : "آب",
    "Sep." : "أيلول",
    "Oct." : "تشرين الأول",
    "Nov." : "تشرين الثاني",
    "Dec." : "كانون الأول",
    "Settings" : "إعدادات",
    "Saving..." : "جاري الحفظ...",
    "Dismiss" : "تراجع",
    "seconds ago" : "منذ ثواني",
    "I know what I'm doing" : "أعرف ماذا أفعل",
    "Password can not be changed. Please contact your administrator." : "كلمة المرور لا يمكن تغييرها. فضلاً تحدث مع المسؤول",
    "No" : "لا",
    "Yes" : "نعم",
    "Choose" : "اختيار",
    "Ok" : "موافق",
    "read-only" : "قراءة فقط",
    "New Files" : "ملفات جديدة",
    "Already existing files" : "المفات موجودة مسبقاً",
    "Which files do you want to keep?" : "ماهي الملفات التي ترغب في إبقاءها ؟",
    "If you select both versions, the copied file will have a number added to its name." : "عند إختيار كلا النسختين. المف المنسوخ سيحتوي على رقم في إسمه.",
    "Cancel" : "الغاء",
    "Continue" : "المتابعة",
    "(all selected)" : "(إختيار الكل)",
    "Very weak password" : "كلمة السر ضعيفة جدا",
    "Weak password" : "كلمة السر ضعيفة",
    "Good password" : "كلمة السر جيدة",
    "Strong password" : "كلمة السر قوية",
    "Shared" : "مشارك",
    "Error" : "خطأ",
    "Error while sharing" : "حصل خطأ عند عملية المشاركة",
    "Error while unsharing" : "حصل خطأ عند عملية إزالة المشاركة",
    "Error setting expiration date" : "حصل خطأ عند عملية تعيين تاريخ إنتهاء الصلاحية",
    "Set expiration date" : "تعيين تاريخ إنتهاء الصلاحية",
    "Expiration" : "إنتهاء",
    "Expiration date" : "تاريخ إنتهاء الصلاحية",
    "Choose a password for the public link" : "اختر كلمة مرور للرابط العام",
    "Resharing is not allowed" : "لا يسمح بعملية إعادة المشاركة",
    "Share link" : "شارك الرابط",
    "Link" : "الرابط",
    "Password protect" : "حماية كلمة السر",
    "Password" : "كلمة المرور",
    "Allow editing" : "السماح بالتعديلات",
    "Email link to person" : "ارسل الرابط بالبريد الى صديق",
    "Send" : "أرسل",
    "Sending ..." : "جاري الارسال ...",
    "Email sent" : "تم ارسال البريد الالكتروني",
    "Shared with you and the group {group} by {owner}" : "شورك معك ومع المجموعة {group} من قبل {owner}",
    "Shared with you by {owner}" : "شورك معك من قبل {owner}",
    "group" : "مجموعة",
    "remote" : "عن بعد",
    "notify by email" : "الإشعار عن طريق البريد",
    "Unshare" : "إلغاء مشاركة",
    "can share" : "يمكن المشاركة",
    "can edit" : "التحرير مسموح",
    "create" : "إنشاء",
    "change" : "تغيير",
    "delete" : "حذف",
    "access control" : "ضبط الوصول",
    "Share" : "شارك",
    "Warning" : "تحذير",
    "Delete" : "إلغاء",
    "Rename" : "إعادة التسمية",
    "The object type is not specified." : "نوع العنصر غير محدد.",
    "Enter new" : "إدخال جديد",
    "Add" : "اضف",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud community</a>." : "حصل خطأ في عملية التحديث, يرجى ارسال تقرير بهذه المشكلة الى <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud community</a>.",
    "The update was successful. Redirecting you to ownCloud now." : "تم التحديث بنجاح , يتم اعادة توجيهك الان الى Owncloud",
    "Personal" : "شخصي",
    "Users" : "المستخدمين",
    "Apps" : "التطبيقات",
    "Admin" : "المدير",
    "Help" : "المساعدة",
    "Access forbidden" : "التوصّل محظور",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "مجلدات البيانات والملفات الخاصة قد تكون قابلة للوصول اليها عن طريق شبكة الانترنت وذلك بسبب ان ملف .htaccess  لا يعمل بشكل صحيح.",
    "Create an <strong>admin account</strong>" : "أضف </strong>مستخدم رئيسي <strong>",
    "Username" : "إسم المستخدم",
    "Data folder" : "مجلد المعلومات",
    "Configure the database" : "أسس قاعدة البيانات",
    "Database user" : "مستخدم قاعدة البيانات",
    "Database password" : "كلمة سر مستخدم قاعدة البيانات",
    "Database name" : "إسم قاعدة البيانات",
    "Database tablespace" : "مساحة جدول قاعدة البيانات",
    "Database host" : "خادم قاعدة البيانات",
    "Finish setup" : "انهاء التعديلات",
    "Log out" : "الخروج",
    "Search" : "البحث",
    "Log in" : "أدخل",
    "Alternative Logins" : "اسماء دخول بديلة",
    "Use the following link to reset your password: {link}" : "استخدم هذه الوصلة لاسترجاع كلمة السر: {link}",
    "New password" : "كلمات سر جديدة",
    "Reset password" : "تعديل كلمة السر"
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
